@@ -116,9 +116,11 @@ class SimulatedAnnealingSampler(dimod.Sampler, dimod.Initialized):
                 The binary quadratic model to be sampled.
 
             beta_range (tuple, optional):
-                A 2-tuple defining the beginning and end of the beta schedule, where beta is the
-                inverse temperature. The schedule is applied linearly in beta. Default range is set
-                based on the total bias associated with each node.
+                A 2-tuple defining the beginning and end of the beta schedule,
+                where beta is the inverse temperature. The schedule is
+                interpolated within this range according to the value specified
+                by `beta_schedule_type`. Default range is set based on the total
+                bias associated with each node.
 
             num_reads (int, optional, default=len(initial_states) or 1):
                 Number of reads. Each read is generated by one run of the simulated
@@ -231,8 +233,7 @@ class SimulatedAnnealingSampler(dimod.Sampler, dimod.Initialized):
 
         # read out the BQM
         ldata, (irow, icol, qdata), off = bqm.to_numpy_vectors(
-            variable_order=variable_order,
-            dtype=np.double, index_dtype=np.intc)
+            variable_order=variable_order)
 
         if interrupt_function and not callable(interrupt_function):
             raise TypeError("'interrupt_function' should be a callable")
